<?
/*
 * Flatnuke http://www.flatnuke.org/
 * English translation
 *
 * Author/s:	Simone Vellei <simone_vellei@users.sourceforge.net>
 *				Marco Segato <segatom@users.sourceforge.net>
 */

$giorni = array("Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday");
$mesi = array("January","February","March","April","May","June","July","August","September","October","November","December");

//su alcune piattaforme  necessario...
$GLOBALS['giorni'] = $giorni;
$GLOBALS['mesi'] = $mesi;

define("_CHARSET","ISO-8859-1");
define("_CERCA","Find");
define("_CERCASTR","Find word in:");
define("_ALLSITE","All the site");
define("_POSTATO","Posted ");
define("_LETTO","read ");
define("_VOLTE","times");
define("_LEGGITUTTO","Read all");
define("_COMMENTI","Comments");
define("_STAMPA","Print");
define("_INDIETRO","Back");
define("_PERARGOMENTI","By topic");
define("_TITNOTIZIA","News title");
define("_ARGOMENTO","Topic");
define("_INTMESSAGGIO","Message header");
define("_CORPOMESSAGGIO","Message body");
define("_PASSWORD","Password");
define("_INSNOTIZIA","Add news");
define("_SEGNEWS","Propose News");
define("_ANTEPRIMA","Preview");
define("_SEGNNOTIZIE","Highlighted news");
define("_LEGGI","Read");
define("_TUONOME","Your name");
define("_BACKEND","Download RSS/RDF file");
define("_MOTD","Welcome message");
define("_MODIFICA","Edit");
define("_NOMEUTENTE","Username");
define("_LOGIN","Log in");
define("_LOGOUT","Log out");
define("_NONREG","Have you registered yet?");
define("_REGORA","Register now!");
define("_BENVENUTO","Welcome");
define("_ADDNEWS","Add news");
define("_MODMOTD","Edit welcome message");
define("_DATA","Date");
define("_ORA","Time");
define("_PASSERR","Wrong password");
define("_ALERTSIG","Your highlight has been forwarded to the admin who will publish it");
define("_PUBNEWS","Publish");
define("_DELNEWS","Delete");
define("_HASCRITTO","wrote");
define("_NONPUOI", "You may not do that!");
define("_ADDCOMM", "Add a comment");
define("_DEVIREG", "You must be registered to");
define("_DEVIREG2", "to add a comment!");
define("_DEVIREG3", "to highlight news!");
define("_NORSS", "Can't find RSS file!");
define("_ARTTR","Article published on:");
define("_URLREF","Reference URL:");
define("_DA","By:");
define("_ELIMINA","Delete");
define("_MAINMENUTITLE", "Navigation");
define("_HOMEMENUTITLE", "Home");
define("_REMEMBERLOGIN", "Remember me");
define("_SITEURL","Site URL");
define("_SITENAME","Site name");
define("_THEME","FlatNuke theme");
define("_NEWSPP","Visibles news in the home page");
define("_ADMIN","Webmaster name");
define("_ADMINM","Webmaster mail");
define("_LANG","Site language");
define("_GUESTN","Unregistered users can highlight news");
define("_GUESTC","Unregistered users can highlight comments");
define("_FUSO","Timezone difference between the server and locale");
define("_TOPICPP","Forum topics per page");
define("_POSTPP","Forum posts per page");
define("_MEMBRIPP","Forum members per page");
define("_SECTNOTEXIST","Section doesn't exists!");
define("_NORESULT","No matching results");
define("_RELATEDNEWSLAST","Latest news about this argument");
define("_RELATEDNEWSALL","All the news about this argument");
define("_NOPREVNEWS","No older news");
define("_PREVNEWS","Previous news");
define("_NONEXTNEWS","No more recent news");
define("_NEXTNEWS","Next news");
define("_GOTOSECTION","Go to the section");
define("_VIEW_USERPROFILE","View user's profile");
define("_FREG","REGISTRATION");
define("_FCAMPI","*=required fields");
define("_FNOME","Name");
define("_FEMAIL","E-mail");
define("_FHOME","Homepage");
define("_FPROFES","Job");
define("_FPROV","Provenience");
define("_FAVAT","Avatar");
define("_FAVATREM","Or address of a remote image");
define("_FFIRMA","Signature");
define("_FNUOVOTOP","New thread");
define("_FTITTOP","Thread title");
define("_FNPAG","Pages");
define("_FNMESS","Messages");
define("_FINIPOST","First message");
define("_FULTPOST","Last message");
define("_FLOGIN","LOG IN");
define("_FERRCAMPO","You skipped some fields or you made some error: valid characters (max. 13) for the name are a-z, A-Z, 0-9");
define("_FORAREG","You are now registered");
define("_FUSERSCE","Username already taken");
define("_FNONREG","You're not registered yet!");
define("_FERRPASS","you put in a wrong password!");
define("_FERRACC","This function is reserved to registered users!");
define("_FMODPROF","Edit profile");
define("_FMODPROFTIT","EDIT PROFILE of");
define("_FDIVERS","only if different");
define("_FINVIA","Send");
define("_FOKMODPROF","Profile has been modified");
define("_FRISP","Reply");
define("_FUTENTE","User");
define("_FMESS","Message");
define("_FNUOVOMESS","New message");
define("_FOGG","Subject");
define("_FTOPOK","Thread created");
define("_FLEGGI","Read");
define("_FMESSOK","Message sent");
define("_FIND","Forum Index");
define("_FINDH","Home Page");
define("_BENVE","Welcome");
define("_SCON","unknown");
define("_FGUIDA","Help");
define("_FUTENTI","registered users");
define("_FDELUTENTE","Delete account");
define("_REG_AGREEMENT_TERMS","While the administrators and moderators of this forum will attempt to remove or edit any generally
objectionable material as quickly as possible, it is impossible to review every message. Therefore you acknowledge that all posts
made to these forums express the views and opinions of the author and not the administrators, moderators or webmaster (except
for posts by these people) and hence will not be held liable.<br /><br />You agree not to post any abusive, obscene, vulgar, slanderous,
hateful, threatening, sexually-oriented or any other material that may violate any applicable laws. Doing so may lead to you
being immediately and permanently banned (and your service provider being informed). The IP address of all posts is recorded
to aid in enforcing these conditions. You agree that the webmaster, administrator and moderators of this forum have the right
to remove, edit, move or close any topic at any time should they see fit. As a user you agree to any information you have entered
above being stored in a database. While this information will not be disclosed to any third party without your consent the
webmaster, administrator and moderators cannot be held responsible for any cracking attempt that may lead to the data being
compromised.<br /><br />This forum system uses cookies to store information on your local computer. These cookies do not contain
any of the information you have entered above; they serve only to improve your viewing pleasure. The e-mail address is not
actually used in any automatic function.<br /><br />By clicking Register below you agree to be bound by these conditions."); // taken & modified from PhpBB (http://www.phpbb.com/)
define("_LEGAL","This is a free software released under the GNU General Public License.");
define("_NOPUBNEWS","No highlighted news");
define("_MOTDMESS","Welcome to <b>FlatNuke</b><br /><br /><b>FlatNuke</b> is a CMS (Content Management System) that makes no use of
DBMS, but only text files (so its name).<br /><b>FlatNuke</b> home page is <a href=\"http://www.flatnuke.org/\">this</a>.<br /><br />
<b>ATTENTION! </b><br />To train the site you need to create at least one account, <b>the first user you register will be the
administrator</b> (with all permissions)! &gt;&gt;<a href=\"forum/index.php?op=vis_reg\">CREATE IT NOW!</a>&lt;&lt;<br /><br />
If you like FlatNuke <b>send me a postcard</b> from your city! You can find my address into the file AUTHOR");
define("_LEVEL","Level");
define("_NOLEVELSECT","You don't have right permissions to view this section");
define("_SICURO","Are you sure you want to do it?");
define("_FP_VOTA","Vote!");
define("_FP_RISULTATI","Results");
define("_FP_SONDAGGI","Polls");
define("_FP_VECCHI","old polls");
define("_FP_ADMIN","Admin");
define("_FP_VOTITOTALI","total votes");
define("_FP_VOTI","Votes");
define("_FP_GIAVOTATO","YOU ALREADY VOTED! You can only make a choice every");
define("_FP_ORE","hours");
define("_FP_VOTONONVALIDO","You didn't select any option, not a valid vote!");
define("_FP_COMMENTI","Comments");
define("_FP_ADDCOMM","Add a comment");
define("_FP_DA","By:");
define("_FP_SCON","unknown");
define("_FP_FINVIA","Send");
define("_FP_DEVIREG","You must be registered to");
define("_FP_DEVIREG2","to add a comment!");
define("_FP_NOACTIVE","No active poll at this moment:");
define("_FP_STATOSONDAGGIO","Poll status");
define("_FP_APERTO","Open");
define("_FP_DOMANDASONDAGGIO","Poll question");
define("_FP_ISTRUZIONIMODIFICA","Insert down here the options that can be voted by users:
					to make an option to be valid, it must have <strong>
					AND option AND vote</strong>, so if you create a new answer
					you have to insert <strong>0</strong> as number of votes!");
define("_FP_OPZIONENUM","Option number");
define("_FP_MODIFICA","Change");
define("_FP_CHIUDIARCHIVIA","Close and store");
define("_FP_MODIFICAOK","The poll has been changed!");
define("_FP_NUOVOSONDAGGIO","New poll");
define("_FP_OPZIONE","Option");
define("_FP_ARCHIVEOK","The poll has been stored!");
define("_FP_DELETEOK1","The poll closed on");
define("_FP_DELETEOK2","has been deleted!");
define("_FP_CHIUSO","Closed");
define("_FP_ELIMINA","Delete");
define("_FP_NONEOLD","No stored polls.");
define("_FIG_TXT_PAGINA","Page ");
define("_FIG_TXT_NOGD","<b>Error</b>: No GD library found (PHP)!");
define("_FIG_TXT_NOIMAGES","No images.");
define("_FIG_ADMIN_SECT","Administration of the image gallery");
define("_FIG_TXT_NUMCOLSROWS","Images table dimensions: ");
define("_FIG_TXT_NUMCOLS","columns ");
define("_FIG_TXT_NUMROWS"," rows ");
define("_FIG_TXT_DIMTHUMBS","Thumbs' heigth/width (default 175px): ");
define("_FIG_TXT_REGUPLOADS","Let registered users upload images (Y/N): ");
define("_FIG_TXT_COMMENTI","Let write comments (Y/N): ");
define("_FIG_TXT_DELCOMM","Empty file with comments ");
define("_FIG_TXT_UPLOAD","Add a new image to the gallery: ");
define("_FIG_TXT_RENAME","Rename image: ");
define("_FIG_TXT_DELETE","Delete an uploaded image: ");
define("_FIG_ALERTNOTWR","Not writeable directory");
define("_FIG_ALERTNOTIMG","Uploaded file is not an image");
define("_FIG_ALERTIMGDEL","Image deleted");
define("_FIG_ALERTEXIST","Attention, file already exists");
define("_FIG_ALERTUPOK","File uploaded");
define("_FIG_COMMENTI","Comments");
define("_FIG_ADDCOMM","Add a comment");
define("_FIG_DA","By:");
define("_FIG_SCON","unknown");
define("_FIG_FINVIA","Send");
define("_FIG_RENAMEOK","Image renamed!");
define("_FIG_RENAMENO","Image not renamed!");
define("_FIG_DEVIREG","You must be registered to");
define("_FIG_DEVIREG2","to add a comment!");
define("_FIG_INGRANDIRE","Click to enlarge");
define("_MAINT","ATTENTION: site in work.");
define("_MAINT_MSG","The administrator(s) can login through the form below:");
define("_FASTNEWSSTR","Add this link to your bookmarks and use it to publish news in a very fast and simple way:");

// 2.6
define("_SPAMALERT","The text of your message is marked as spam. Please click on \"back\" and edit your message.");
define("_SEARCHDESC","Search contents on this site.");
define("_ADVSEARCH","Advanced search");
define("_ARGUMENT","Argument");
define("_TOPICS","Topics");
define("_VIEWGROUPTITLE","View the group");
define("_VIEWARGUMENTTITLE","View the argument");
define("_VIEWTOPICTITLE","View the topic");
define("_ADMINS","Administrators");
define("_MODERATORS","Moderators");
define("_DELETEGROUP","Delete group");
define("_RENAMEGROUP","Rename group");
define("_RENAME","Rename");
define("_MOVE","Move");
define("_LOCK","Lock");
define("_UNLOCK","Unlock");
define("_RENAMEARGTITLE","Rename the argument");
define("_EDITARGTITLE","Edit the argument");
define("_MOVEARGTITLE","Move the argument");
define("_LOCKARGTITLE","Lock the argument");
define("_UNLOCKARGTITLE","Unlock the argument");
define("_DELETEARGTITLE","Delete the argument");
define("_THEARGUMENT","the argument");
define("_FFCONTROLPANEL","Forum's Control Panel");
define("_NEWGROUP","New Group");
define("_NEWARGUMENT","New Argument");
define("_GOTOTHEPAGE","Go to the page");
define("_GOTOTHEFIRSTPAGE","Go to the first page");
define("_GOTOTHELASTPAGE","Go to the last page");
define("_GOTOTHEPREVIOUSPAGE","Go to the previous page");
define("_GOTOTHENEXTPAGE","Go to the next page");
define("_EDITTOPIC","Edit the topic");
define("_DELETETOPIC","Delete the topic");
define("_MOVETOPIC","Move the topic");
define("_STICKYTOPIC","Sticky topic");
define("_UNSTICKYTOPIC","Normal topic");
define("_HIDETOPIC","Hide the topic");
define("_SHOWTOPIC","Show the topic");
define("_LOCKTOPIC","Lock the topic");
define("_UNLOCKTOPIC","Unlock the topic");
define("_STICKY","Sticky");
define("_UNSTICKY","Unsticky");
define("_HIDE","Hide");
define("_SHOW","Show");
define("_QUOTE","Quote");
define("_POSTSTICKY","Sticky");
define("_NORMAL","Normal");
define("_QUOTEPOST","Quote the post");
define("_EDITPOST","Edit post");
define("_STICKYPOST","Show the post on top");
define("_NORMALPOST","Show the post in normal position");
define("_DELETEPOST","Delete post");
define("_MAILALERT","Mail notification for new posts");
define("_REMOVEMAILALERT","Remove mail notification for new posts");
define("_VIEWFORUMHOME","View forum's home page");
define("_FORUMBACKUP","Do forum backup");
define("_EDITFORUMMOTD","Edit forum's motd");
define("_EDITFORUMHELP","Edit help message of the forum");
define("_EDITFLANUKECONFIG","Edit Flatnuke's config file");
define("_EDITFORUMTHEME","Edit forum's theme");
define("_EDITSPAMFILTER","Edit spam filter");
define("_EDITFORUMRULES","Edit forum's rules");
define("_FORUMMANAGEMENT","Forum management");
define("_CONFIG","Configuration");
define("_CHOOSEGROUPNAME","Choose group's name");
define("_CREATEGROUP","Create group");
define("_GROUPCREATED","Group created!");
define("_THEGROUP","The group");
define("_ALREADYEXISTS","already exists. Please choose another name.");
define("_RETURN","Return");
define("_GROUPNOCHANGE","Attention! Group's name isn't changed!");
define("_GROUPRENAMED","Group successfully renamed!");
define("_DOESNTEXISTS","doesn't exists!");
define("_ATTENTION","Attention");
define("_DELETEGROUPALERT1","Do you really want to delete the group");
define("_DELETEGROUPALERT2","If you want to delete the group you have to check the form below and clik on the OK button.<br /><b>Attention:</b> the group will be deleted only if it doesn't contain any argument.");
define("_DELETEGROUPALERT3","Definitively delete the group");
define("_DELETEGROUPNOCONFIRM","If you want to delete the group you have to check the checkbox in the previous page.");
define("_DELETEGROUPOK","Group successfully deleted!");
define("_GROUPNOTEMPTY","isn't empty and contains one ore more arguments. <br />You will have to delete or move arguments before try to delete the group.");
define("_ARGUMENTGROUP","Choose a group for the argument");
define("_ARGUMENTNAME","Choose the name of the argument");
define("_ARGUMENTLEVEL","Select a level");
define("_ARGUMENTIMAGE","Choose an image for the argument");
define("_ARGUMENTDESC","Write a description");
define("_CREATEARGUMENT","Create argument");
define("_ARGUMENTCREATED","Argument created");
define("_ARGUMENTEXISTS","already exists in the group");
define("_ARGUMENTCHANGENAME","change the name or choose another group.");
define("_RENAMEARGUMENT","Rename argument");
define("_RENAMETHEARGUMENT","Rename the argument");
define("_ARGUMENTRENAMED","Argument successfully renamed");
define("_SIZE","Size");
define("_ARGUMENTEDIT","Edit argument");
define("_ARGUMENTEDITED","Argument edited");
define("_ARGUMENTMOVE","Choose in wich group to move the argument");
define("_ARGUMENTMOVED","Argument successfully moved");
define("_NOGROUP","There isn't a group where to move the argument");
define("_NOTWRITABLE","isn't writable");
define("_ARGUMENTLOCKED","Argument locked");
define("_ARGALREADYLOCKED","The argument was already locked");
define("_ARGUMENTUNLOCKED","Argument unlocked");
define("_ARGALREADYUNLOCKED","The argument was already unlocked");
define("_DELETEARGUMENT1","Do you really want delete the argument");
define("_DELETEARGUMENT2","inside the group");
define("_DELETEARGUMENT3","If you want do that please check the checkbox present below and press the OK button.<br /><b>Attention</b>: all topic contained will be deleted!");
define("_DELETEARGUMENT","delete the argument");
define("_ARGUMENTDELETED","Argument successfully deleted");
define("_DIRNOTDELETED","It was impossible to delete the dir");
define("_FILENOTDELETED","It was impossible to delete the file");
define("_DELETEARGNOCONFIRM","If you want to delete the argument you have to check the checkbox in the previous page.");
define("_THEFILE","the file");
define("_ASKDELETETOPIC","Are you sure do you want to delete the topic");
define("_TOPICDELETED","Topic deleted");
define("_CHOOSETOPICDEST","Choose where to move the topic");
define("_TOPICMOVED","Topic moved");
define("_TOPICNOTMOVED","It was impossible to move the topic");
define("_TOPICHIDDEN","The topic is hidden");
define("_TOPICSHOWED","The topic is shown");
define("_TOPICLOCKED","The topic is locked");
define("_TOPICUNLOCKED","The topic is unlocked");
define("_VIEWFFLOG","View Flatforum's log");
define("_VIEWFFERRORLOG","View Flatforum's error log");
define("_ISSPAM","is considered spam");
define("_LASTEDITBY","Last edit by");

//2.7
define("_HIDDENMAIL","E-mail not visible");
define("_POSTDELETED","Post deleted!");
define("_THEDIR","The directory");
define("_COMP_REG","It has been sended one email to you to the address:");
define("_COMP_REG2"," with the instructions to complete the registration");
define ("_ERREMAIL","E-mail address is not valid");
define("_IST_REG_MAIL","To complete the registration click on the following link:");
define("_COMP_REG_MAIL","Complete registration on");
define("_THEMAIL","The e-mail");
define("_MAILUSED","was already used for the registration of a user. Every e-mail address can be used only for the registration of one user.");
define("_ACTIVATIONMAILNOTSENT","I was not able to send to you a mail with the activation code. Please contact the administrator of this site.");
define("_WAITINGUSERLOGIN","You need to complete the registration process. Please follow the instructions sent you by e-mail.");
define("_CONTACTADMIN","If you experience any problem, please contact the admin of the site");
define("_MANAGESECTION","Manage section");
define("_MANAGEFILE","Manage file");
define("_FNCREATESUBSECTION","Create subsection");
define("_FNCREATEFILE","Create file");
define("_FNRENAMESECTION","Rename section");
define("_FNDELETESECTION","Delete section");
define("_FNRENAMEFILE","Rename file");
define("_FNDELETEFILE","Delete file");
define("_FNMOVESECTION","Move section");
define("_FNMOVEFILE","Move file");
define("_FNSECTIONPERM","Section permissions");
define("_FNSECTIONRENAMED","Section renamed");
define("_CREATE","Create");
define("_FNSECTIONCREATED","Section created");
define("_FNSECTIONDELETED","Section deleted");
define("_FNSECTIONMOVED","Section moved");
define("_FNFILECREATED","File created");
define("_ERROR","Error");
define("_FNFILEDELETED","File deleted");
define("_MANAGEFLATNUKE","Manage Flatnuke");
define("_FNFILERENAMED","File renamed");
define("_GOTOFILE","Go to file");
define("_FNCHOOSEDEST","Choose destination");
define("_FNFILEMOVED","File moved");
define("_EDITHTML","Edit html code");
define("_EDITFCKEDITOR","Edit with FCKEditor");
define("_FNCHOOSEEDITOR","Choose the editor");
define("_DELETESUBSECTIONS","You need to delete alla subsections");
define("_FNVIEWPERMS","View permissions");
define("_FNEDITPERMS","Edit permissions");
define("_FNADDUSER","Add user");
define("_FNREMOVEUSER","Remove user");
define("_USERS","Users");
define("_FNEDITSECTION","Edit section");
define("_FNEDITFILE","Edit file");
define("_FNMANAGESECTTITLE","Admin options for the current section");
define("_FNMANAGEFILETITLE","Admin options for the current file");
define("_FNMANAGEVIEWPERMSTITLE","Set view permissions for the current section");
define("_FNUSERADDED","User added");
define("_FNCHOOSEUSER","You must choose a user");
define("_FNUSERREMOVED","User removed");
define("_FNWRITEPERMS","Write permissions");
define("_FNMANAGEEDITPERMSTITLE","Set edit permissions for the current section");
define("_FNEDITALLOW1","Allow the user");
define("_FNEDITALLOW2","to edit the section");
define("_CANCEL","Cancel");
define("_SECTIONTYPE","Section type");
define("_STANDARD","Standard");
define("_DOWNLOADMAIN","Download (with subcategories)");
define("_DOWNLOADSINGLE","Download (single section)");
define("_DOWNLOADMAINTITLE","Create a section that show files present in subsections");
define("_DOWNLOADSINGLETITLE","Permit to load files in the section");
define("_ISNOTADIR","is not a directory");
define("_ISNOTAFILE","is not a file");
define("_CHANGESECTTYPE","Change section type");
define("_EXEC","Exec");//check translation
define("_CHOOSEACTION","Choose action");
define("_MANAGESECTNOTE","Edit section's text or choose an admin option on the right");
define("_FNPRESENTATION","Presentation");//check translation

// 2.7.1
define("_NEWPWDSTRING","Lost password");
define("_NEWPWDFORM","<b>Recover Password</b>:<br /><br />
	To recover your password, please provide the e-mail address you have
	associated with your member account and click on the Submit button.<br />
	The e-mail will also contain your NEW password.<br />
	Pay attention on the fact that you will not be able to use your new password
	till you will validate the request; so, without validation,
	you still have to use the old password.");
define("_NEWPWDFROM","Recover password from:");
define("_NEWPWDMAIL","Hi __USERNAME__,\n
this email has been sent to you from __SITEURL__ because someone asked to
provide a new password for your account.\n
If you didn't request anything, just ignore this email: your password
will remain the same. To avoid errors or abuses, only you are able
to validate password recovery.\n
*** Continue only if you want to recover your password ***\n
------------------------------------------------
HOW TO VALIDATE THE REQUEST
------------------------------------------------\n
To validate your request, just click on link below:\n
__URLCONFIRMPASSWORDCHANGE__\n
(your e-mail program should open the download page in your browser;
if your e-mail program does not do this, you can paste the URL in your browser
and press the Enter key to open the link).\n
Once this process of activation/validation will be completed,
you can login to the site using the new password you can find below.
You can change your password at any time by editing your account information.\n
------------------------------------------------
YOUR NEW PASSWORD (AFTER VALIDATION)
------------------------------------------------\n
Use your new password only after visiting the link in this e-mail.\n
After validation, your new password will be: __REGCODE__\n
Keep your password secure and do not share it with other people.
You can change your password at any time by editing your account information.");
?>